@@ -1,7 +1,7 @@
 <?php
 # Graph WikiMedia extension
 
-# (c) by Tels http://bloodgate.com 2004-2005
+# (c) by Tels http://bloodgate.com 2004-2006
 
 # Takes text between <graph> </graph> tags, and runs it through the
 # external script "graphcnv", which generates an ASCII, HTML or SVG
@@ -20,11 +20,11 @@ function wfGraphExtension() {
 
 # for Special::Version:
 
-$wgExtensionCredits[parserhook][] = array(
+$wgExtensionCredits['parserhook'][] = array(
 	'name' => 'graph extension',
 	'author' => 'Tels',
 	'url' => 'http://wwww.bloodgate.com/perl/graph/',
-	'version' => 'v0.17 using Graph::Easy v' . `perl -MGraph::Easy -e 'print \$Graph::Easy::VERSION'`,
+	'version' => 'v0.18 using Graph::Easy v' . `perl -MGraph::Easy -e 'print \$Graph::Easy::VERSION'`,
 );
  
 # The callback function for converting the input text to HTML output
